summaryrefslogtreecommitdiff
path: root/sysdeps/ieee754/ldbl-128ibm/s_nextafterl.c
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/ieee754/ldbl-128ibm/s_nextafterl.c')
-rw-r--r--sysdeps/ieee754/ldbl-128ibm/s_nextafterl.c12
1 files changed, 9 insertions, 3 deletions
diff --git a/sysdeps/ieee754/ldbl-128ibm/s_nextafterl.c b/sysdeps/ieee754/ldbl-128ibm/s_nextafterl.c
index bf57cb89d6..515aa1ef5b 100644
--- a/sysdeps/ieee754/ldbl-128ibm/s_nextafterl.c
+++ b/sysdeps/ieee754/ldbl-128ibm/s_nextafterl.c
@@ -24,6 +24,8 @@ static char rcsid[] = "$NetBSD: $";
* Special cases:
*/
+#include <errno.h>
+#include <float.h>
#include <math.h>
#include <math_private.h>
#include <math_ldbl_opt.h>
@@ -68,6 +70,7 @@ long double __nextafterl(long double x, long double y)
if((hx==0xffefffffffffffffLL)&&(lx==0xfc8ffffffffffffeLL)) {
u = x+x; /* overflow, return -inf */
math_force_eval (u);
+ __set_errno (ERANGE);
return y;
}
if (hx >= 0x7ff0000000000000LL) {
@@ -76,12 +79,13 @@ long double __nextafterl(long double x, long double y)
}
if(ihx <= 0x0360000000000000LL) { /* x <= LDBL_MIN */
u = math_opt_barrier (x);
- x -= __LDBL_DENORM_MIN__;
+ x -= LDBL_TRUE_MIN;
if (ihx < 0x0360000000000000LL
|| (hx > 0 && lx <= 0)
|| (hx < 0 && lx > 1)) {
u = u * u;
math_force_eval (u); /* raise underflow flag */
+ __set_errno (ERANGE);
}
return x;
}
@@ -107,6 +111,7 @@ long double __nextafterl(long double x, long double y)
if((hx==0x7fefffffffffffffLL)&&(lx==0x7c8ffffffffffffeLL)) {
u = x+x; /* overflow, return +inf */
math_force_eval (u);
+ __set_errno (ERANGE);
return y;
}
if ((uint64_t) hx >= 0xfff0000000000000ULL) {
@@ -115,14 +120,15 @@ long double __nextafterl(long double x, long double y)
}
if(ihx <= 0x0360000000000000LL) { /* x <= LDBL_MIN */
u = math_opt_barrier (x);
- x += __LDBL_DENORM_MIN__;
+ x += LDBL_TRUE_MIN;
if (ihx < 0x0360000000000000LL
|| (hx > 0 && lx < 0 && lx != 0x8000000000000001LL)
|| (hx < 0 && lx >= 0)) {
u = u * u;
math_force_eval (u); /* raise underflow flag */
+ __set_errno (ERANGE);
}
- if (x == 0.0L) /* handle negative __LDBL_DENORM_MIN__ case */
+ if (x == 0.0L) /* handle negative LDBL_TRUE_MIN case */
x = -0.0L;
return x;
}